pub struct GatewayBond {
pub pledge_amount: Coin,
pub owner: Addr,
pub block_height: u64,
pub gateway: Gateway,
pub proxy: Option<Addr>,
}Expand description
Basic gateway information provided by the node operator.
Fields
pledge_amount: CoinOriginal amount pledged by the operator of this node.
owner: AddrAddress of the owner of this gateway.
block_height: u64Block height at which this gateway has been bonded.
gateway: GatewayInformation provided by the operator for the purposes of bonding.
proxy: Option<Addr>Entity who bonded this gateway on behalf of the owner. If exists, it’s most likely the address of the vesting contract.
Implementations