pub struct MixNodeDetails {
pub bond_information: MixNodeBond,
pub rewarding_details: NodeRewarding,
pub pending_changes: PendingMixNodeChanges,
}Expand description
Full details associated with given mixnode.
Fields
bond_information: MixNodeBondBasic bond information of this mixnode, such as owner address, original pledge, etc.
rewarding_details: NodeRewardingDetails used for computation of rewarding related data.
pending_changes: PendingMixNodeChangesAdjustments to the mixnode that are ought to happen during future epoch transitions.
Implementations
Sourceimpl MixNodeDetails
impl MixNodeDetails
pub fn new( bond_information: MixNodeBond, rewarding_details: NodeRewarding, pending_changes: PendingMixNodeChanges, ) -> MixNodeDetails
pub fn mix_id(&self) -> u32
pub fn is_unbonding(&self) -> bool
pub fn original_pledge(&self) -> &Coin
pub fn pending_operator_reward(&self) -> Coin
pub fn pending_detailed_operator_reward(&self) -> Result<Decimal, StdError>
pub fn total_stake(&self) -> Decimal
pub fn pending_pledge_change(&self) -> Option<u32>