pub struct NymApiClient {
pub use_bincode: bool,
pub nym_api: Client,
}Use nym_http_api_client::Client::from_network() or ClientBuilder::with_bincode() instead
DEPRECATED: Use nym_http_api_client::Client with from_network() or with_bincode() instead
Fields
use_bincode: boolUse nym_http_api_client::Client::from_network() or ClientBuilder::with_bincode() instead
nym_api: ClientUse nym_http_api_client::Client::from_network() or ClientBuilder::with_bincode() instead
Implementations
Sourceimpl NymApiClient
impl NymApiClient
pub fn new_with_timeout(api_url: Url, timeout: Duration) -> Self
pub fn with_bincode(self, use_bincode: bool) -> Self
pub fn new_with_user_agent( api_url: Url, user_agent: impl Into<UserAgent>, ) -> Self
pub fn api_url(&self) -> &Url
pub fn change_nym_api(&mut self, new_endpoint: Url)
pub async fn get_basic_mixnodes( &self, ) -> Result<Vec<SkimmedNodeV1>, ValidatorClientError>
use get_all_basic_active_mixing_assigned_nodes instead
pub async fn get_basic_gateways( &self, ) -> Result<Vec<SkimmedNodeV1>, ValidatorClientError>
use get_all_basic_entry_assigned_nodes instead
pub async fn get_current_rewarded_set( &self, ) -> Result<EpochRewardedSet, ValidatorClientError>
Sourcepub async fn get_all_basic_entry_assigned_nodes(
&self,
) -> Result<Vec<SkimmedNodeV1>, ValidatorClientError>
👎Deprecated: use get_all_basic_entry_assigned_nodes_with_metadata instead
pub async fn get_all_basic_entry_assigned_nodes( &self, ) -> Result<Vec<SkimmedNodeV1>, ValidatorClientError>
use get_all_basic_entry_assigned_nodes_with_metadata instead
retrieve basic information for nodes are capable of operating as an entry gateway this includes legacy gateways and nym-nodes
pub async fn get_all_basic_entry_assigned_nodes_with_metadata( &self, ) -> Result<SkimmedNodesWithMetadata, ValidatorClientError>
Sourcepub async fn get_all_basic_active_mixing_assigned_nodes(
&self,
) -> Result<Vec<SkimmedNodeV1>, ValidatorClientError>
👎Deprecated: use get_all_basic_active_mixing_assigned_nodes_with_metadata instead
pub async fn get_all_basic_active_mixing_assigned_nodes( &self, ) -> Result<Vec<SkimmedNodeV1>, ValidatorClientError>
use get_all_basic_active_mixing_assigned_nodes_with_metadata instead
retrieve basic information for nodes that got assigned ‘mixing’ node in this epoch this includes legacy mixnodes and nym-nodes
pub async fn get_all_basic_active_mixing_assigned_nodes_with_metadata( &self, ) -> Result<SkimmedNodesWithMetadata, ValidatorClientError>
Sourcepub async fn get_all_basic_mixing_capable_nodes(
&self,
) -> Result<Vec<SkimmedNodeV1>, ValidatorClientError>
👎Deprecated: use get_all_basic_mixing_capable_nodes_with_metadata instead
pub async fn get_all_basic_mixing_capable_nodes( &self, ) -> Result<Vec<SkimmedNodeV1>, ValidatorClientError>
use get_all_basic_mixing_capable_nodes_with_metadata instead
retrieve basic information for nodes are capable of operating as a mixnode this includes legacy mixnodes and nym-nodes
pub async fn get_all_basic_mixing_capable_nodes_with_metadata( &self, ) -> Result<SkimmedNodesWithMetadata, ValidatorClientError>
Sourcepub async fn get_all_basic_nodes(
&self,
) -> Result<Vec<SkimmedNodeV1>, ValidatorClientError>
👎Deprecated: use get_all_basic_nodes_with_metadata instead
pub async fn get_all_basic_nodes( &self, ) -> Result<Vec<SkimmedNodeV1>, ValidatorClientError>
use get_all_basic_nodes_with_metadata instead
retrieve basic information for all bonded nodes on the network
pub async fn get_all_basic_nodes_with_metadata( &self, ) -> Result<SkimmedNodesWithMetadata, ValidatorClientError>
Sourcepub async fn get_all_expanded_nodes(
&self,
) -> Result<SemiSkimmedNodesWithMetadata, ValidatorClientError>
pub async fn get_all_expanded_nodes( &self, ) -> Result<SemiSkimmedNodesWithMetadata, ValidatorClientError>
retrieve expanded information for all bonded nodes on the network
pub async fn health(&self) -> Result<ApiHealthResponse, ValidatorClientError>
pub async fn get_all_described_nodes( &self, ) -> Result<Vec<NymNodeDescriptionV1>, ValidatorClientError>
use .get_all_described_nodes_v2 instead
pub async fn get_all_described_nodes_v2( &self, ) -> Result<Vec<NymNodeDescriptionV2>, ValidatorClientError>
pub async fn get_all_bonded_nym_nodes( &self, ) -> Result<Vec<NymNodeDetails>, ValidatorClientError>
pub async fn get_gateway_core_status_count( &self, identity: IdentityKeyRef<'_>, since: Option<i64>, ) -> Result<GatewayCoreStatusResponse, ValidatorClientError>
pub async fn get_mixnode_core_status_count( &self, mix_id: NodeId, since: Option<i64>, ) -> Result<MixnodeCoreStatusResponse, ValidatorClientError>
pub async fn blind_sign( &self, request_body: &BlindSignRequestBody, ) -> Result<BlindedSignatureResponse, ValidatorClientError>
pub async fn verify_ecash_ticket( &self, request_body: &VerifyEcashTicketBody, ) -> Result<EcashTicketVerificationResponse, ValidatorClientError>
pub async fn batch_redeem_ecash_tickets( &self, request_body: &BatchRedeemTicketsBody, ) -> Result<EcashBatchTicketRedemptionResponse, ValidatorClientError>
pub async fn partial_expiration_date_signatures( &self, expiration_date: Option<Date>, epoch_id: Option<EpochId>, ) -> Result<PartialExpirationDateSignatureResponse, ValidatorClientError>
pub async fn partial_coin_indices_signatures( &self, epoch_id: Option<EpochId>, ) -> Result<PartialCoinIndicesSignatureResponse, ValidatorClientError>
pub async fn global_expiration_date_signatures( &self, expiration_date: Option<Date>, epoch_id: Option<EpochId>, ) -> Result<AggregatedExpirationDateSignatureResponse, ValidatorClientError>
pub async fn global_coin_indices_signatures( &self, epoch_id: Option<EpochId>, ) -> Result<AggregatedCoinIndicesSignatureResponse, ValidatorClientError>
pub async fn master_verification_key( &self, epoch_id: Option<EpochId>, ) -> Result<VerificationKeyResponse, ValidatorClientError>
pub async fn issued_ticketbooks_for( &self, expiration_date: Date, ) -> Result<IssuedTicketbooksForResponse, ValidatorClientError>
pub async fn issued_ticketbooks_for_count( &self, expiration_date: Date, ) -> Result<IssuedTicketbooksForCountResponse, ValidatorClientError>
pub async fn issued_ticketbooks_challenge_commitment( &self, request: &IssuedTicketbooksChallengeCommitmentRequest, ) -> Result<IssuedTicketbooksChallengeCommitmentResponse, ValidatorClientError>
pub async fn issued_ticketbooks_data( &self, request: &IssuedTicketbooksDataRequest, ) -> Result<IssuedTicketbooksDataResponse, ValidatorClientError>
pub async fn nodes_by_addresses( &self, addresses: Vec<IpAddr>, ) -> Result<NodesByAddressesResponse, ValidatorClientError>