pub struct ConfigScoreDataResponse {
pub parameters: ConfigScoreParams,
pub version_history: Vec<HistoricalNymNodeVersionEntry>,
}Fields
parameters: ConfigScoreParamsversion_history: Vec<HistoricalNymNodeVersionEntry>Trait Implementations
Sourceimpl Clone for ConfigScoreDataResponse
impl Clone for ConfigScoreDataResponse
Sourcefn clone(&self) -> ConfigScoreDataResponse
fn clone(&self) -> ConfigScoreDataResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigScoreDataResponse
impl Debug for ConfigScoreDataResponse
Sourceimpl<'de> Deserialize<'de> for ConfigScoreDataResponse
impl<'de> Deserialize<'de> for ConfigScoreDataResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ConfigScoreDataResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ConfigScoreDataResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConfigScoreDataResponse
impl JsonSchema for ConfigScoreDataResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ConfigScoreDataResponse
impl Serialize for ConfigScoreDataResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more