pub struct ConfigScoreParams {
pub version_weights: OutdatedVersionWeights,
pub version_score_formula_params: VersionScoreFormulaParams,
}Fields
version_weights: OutdatedVersionWeightsDefines weights for calculating numbers of versions behind the current release.
version_score_formula_params: VersionScoreFormulaParamsDefines the parameters of the formula for calculating the version score