pub struct HistoricalNymNodeVersion {
pub semver: String,
pub introduced_at_height: u64,
}Fields
semver: StringVersion of the nym node that is going to be used for determining the version score of a node.
note: value stored here is pre-validated semver::Version
introduced_at_height: u64Block height of when this version has been added to the contract