pub struct HistoricalPerformanceResponse {
pub date: Date,
pub performance: f64,
}Fields
date: Dateperformance: f64Trait Implementations
Sourceimpl Clone for HistoricalPerformanceResponse
impl Clone for HistoricalPerformanceResponse
Sourcefn clone(&self) -> HistoricalPerformanceResponse
fn clone(&self) -> HistoricalPerformanceResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for HistoricalPerformanceResponse
impl<'de> Deserialize<'de> for HistoricalPerformanceResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<HistoricalPerformanceResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<HistoricalPerformanceResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HistoricalPerformanceResponse
impl JsonSchema for HistoricalPerformanceResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for HistoricalPerformanceResponse
impl Serialize for HistoricalPerformanceResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more