pub struct HostKeysV1 {
pub ed25519: PublicKey,
pub x25519: PublicKey,
pub current_x25519_sphinx_key: SphinxKeyV1,
pub pre_announced_x25519_sphinx_key: Option<SphinxKeyV1>,
pub x25519_versioned_noise: Option<VersionedNoiseKeyV1>,
}Fields
ed25519: PublicKeyx25519: PublicKey👎Deprecated:
use the current_x25519_sphinx_key with explicit rotation information
current_x25519_sphinx_key: SphinxKeyV1pre_announced_x25519_sphinx_key: Option<SphinxKeyV1>x25519_versioned_noise: Option<VersionedNoiseKeyV1>Trait Implementations
Sourceimpl Clone for HostKeysV1
impl Clone for HostKeysV1
Sourcefn clone(&self) -> HostKeysV1
fn clone(&self) -> HostKeysV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HostKeysV1
impl Debug for HostKeysV1
Sourceimpl<'de> Deserialize<'de> for HostKeysV1
impl<'de> Deserialize<'de> for HostKeysV1
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<HostKeysV1, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<HostKeysV1, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<HostKeys> for HostKeysV1
impl From<HostKeys> for HostKeysV1
Sourcefn from(value: HostKeys) -> HostKeysV1
fn from(value: HostKeys) -> HostKeysV1
Converts to this type from the input type.
Sourceimpl JsonSchema for HostKeysV1
impl JsonSchema for HostKeysV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HostKeysV1
impl PartialEq for HostKeysV1
Sourcefn eq(&self, other: &HostKeysV1) -> bool
fn eq(&self, other: &HostKeysV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for HostKeysV1
impl Serialize for HostKeysV1
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for HostKeysV1