pub struct SphinxKeyV1 {
pub rotation_id: u32,
pub public_key: PublicKey,
}Fields
rotation_id: u32public_key: PublicKeyTrait Implementations
Sourceimpl Clone for SphinxKeyV1
impl Clone for SphinxKeyV1
Sourcefn clone(&self) -> SphinxKeyV1
fn clone(&self) -> SphinxKeyV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SphinxKeyV1
impl Debug for SphinxKeyV1
Sourceimpl<'de> Deserialize<'de> for SphinxKeyV1
impl<'de> Deserialize<'de> for SphinxKeyV1
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SphinxKeyV1, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SphinxKeyV1, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<SphinxKey> for SphinxKeyV1
impl From<SphinxKey> for SphinxKeyV1
Sourcefn from(value: SphinxKey) -> SphinxKeyV1
fn from(value: SphinxKey) -> SphinxKeyV1
Converts to this type from the input type.
Sourceimpl JsonSchema for SphinxKeyV1
impl JsonSchema for SphinxKeyV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SphinxKeyV1
impl PartialEq for SphinxKeyV1
Sourcefn eq(&self, other: &SphinxKeyV1) -> bool
fn eq(&self, other: &SphinxKeyV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SphinxKeyV1
impl Serialize for SphinxKeyV1
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for SphinxKeyV1