NymApiClientExt

Trait NymApiClientExt 

pub trait NymApiClientExt: ApiClient {
Show 63 methods // Required methods fn api_url(&self) -> &Url; fn change_base_urls(&mut self, urls: Vec<Url>); // Provided methods fn health<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<ApiHealthResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn build_information<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<BinaryBuildInformationOwned, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_node_performance_history<'life0, 'async_trait>( &'life0 self, node_id: NodeId, page: Option<u32>, per_page: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<PerformanceHistoryResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_nodes_described<'life0, 'async_trait>( &'life0 self, page: Option<u32>, per_page: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<PaginatedResponse<NymNodeDescriptionV1>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_nodes_described_v2<'life0, 'async_trait>( &'life0 self, page: Option<u32>, per_page: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<PaginatedResponse<NymNodeDescriptionV2>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_current_rewarded_set<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<RewardedSetResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_all_basic_nodes_with_metadata<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<SkimmedNodesWithMetadata, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_all_basic_active_mixing_assigned_nodes_with_metadata<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<SkimmedNodesWithMetadata, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_all_basic_entry_assigned_nodes_with_metadata<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<SkimmedNodesWithMetadata, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_all_described_nodes<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<Vec<NymNodeDescriptionV1>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_all_described_nodes_v2<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<Vec<NymNodeDescriptionV2>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_nym_nodes<'life0, 'async_trait>( &'life0 self, page: Option<u32>, per_page: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<PaginatedResponse<NymNodeDetails>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_all_bonded_nym_nodes<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<Vec<NymNodeDetails>, ValidatorClientError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_node_families<'life0, 'async_trait>( &'life0 self, page: Option<u32>, per_page: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<PaginatedResponse<NodeFamily>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_all_node_families<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<Vec<NodeFamily>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_basic_mixnodes<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<CachedNodesResponse<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_basic_gateways<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<CachedNodesResponse<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_rewarded_set<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<RewardedSetResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_basic_entry_assigned_nodes<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV1<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_basic_entry_assigned_nodes_v2<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV2<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_basic_active_mixing_assigned_nodes<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV1<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_basic_active_mixing_assigned_nodes_v2<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV2<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_basic_mixing_capable_nodes<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV1<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_basic_mixing_capable_nodes_v2<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV2<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_basic_nodes<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV1<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_basic_nodes_v2<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV2<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_expanded_nodes<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV2<SemiSkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_expanded_nodes_v3<'life0, 'async_trait>( &'life0 self, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV2<SemiSkimmedNodeV3>, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_mixnode_report<'life0, 'async_trait>( &'life0 self, mix_id: NodeId, ) -> Pin<Box<dyn Future<Output = Result<MixnodeStatusReportResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_gateway_report<'life0, 'life1, 'async_trait>( &'life0 self, identity: IdentityKeyRef<'life1>, ) -> Pin<Box<dyn Future<Output = Result<GatewayStatusReportResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait { ... } fn get_mixnode_history<'life0, 'async_trait>( &'life0 self, mix_id: NodeId, ) -> Pin<Box<dyn Future<Output = Result<MixnodeUptimeHistoryResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_gateway_history<'life0, 'life1, 'async_trait>( &'life0 self, identity: IdentityKeyRef<'life1>, ) -> Pin<Box<dyn Future<Output = Result<GatewayUptimeHistoryResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait { ... } fn get_gateway_core_status_count<'life0, 'life1, 'async_trait>( &'life0 self, identity: IdentityKeyRef<'life1>, since: Option<i64>, ) -> Pin<Box<dyn Future<Output = Result<GatewayCoreStatusResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait { ... } fn get_mixnode_core_status_count<'life0, 'async_trait>( &'life0 self, mix_id: NodeId, since: Option<i64>, ) -> Pin<Box<dyn Future<Output = Result<MixnodeCoreStatusResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_current_node_performance<'life0, 'async_trait>( &'life0 self, node_id: NodeId, ) -> Pin<Box<dyn Future<Output = Result<NodePerformanceResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_node_annotation<'life0, 'async_trait>( &'life0 self, node_id: NodeId, ) -> Pin<Box<dyn Future<Output = Result<AnnotationResponseV1, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_node_annotation_v2<'life0, 'async_trait>( &'life0 self, node_id: NodeId, ) -> Pin<Box<dyn Future<Output = Result<AnnotationResponseV2, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_mixnode_avg_uptime<'life0, 'async_trait>( &'life0 self, mix_id: NodeId, ) -> Pin<Box<dyn Future<Output = Result<UptimeResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn blind_sign<'life0, 'life1, 'async_trait>( &'life0 self, request_body: &'life1 BlindSignRequestBody, ) -> Pin<Box<dyn Future<Output = Result<BlindedSignatureResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait { ... } fn verify_ecash_ticket<'life0, 'life1, 'async_trait>( &'life0 self, request_body: &'life1 VerifyEcashTicketBody, ) -> Pin<Box<dyn Future<Output = Result<EcashTicketVerificationResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait { ... } fn batch_redeem_ecash_tickets<'life0, 'life1, 'async_trait>( &'life0 self, request_body: &'life1 BatchRedeemTicketsBody, ) -> Pin<Box<dyn Future<Output = Result<EcashBatchTicketRedemptionResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait { ... } fn partial_expiration_date_signatures<'life0, 'async_trait>( &'life0 self, expiration_date: Option<Date>, epoch_id: Option<EpochId>, ) -> Pin<Box<dyn Future<Output = Result<PartialExpirationDateSignatureResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn partial_coin_indices_signatures<'life0, 'async_trait>( &'life0 self, epoch_id: Option<EpochId>, ) -> Pin<Box<dyn Future<Output = Result<PartialCoinIndicesSignatureResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn global_expiration_date_signatures<'life0, 'async_trait>( &'life0 self, expiration_date: Option<Date>, epoch_id: Option<EpochId>, ) -> Pin<Box<dyn Future<Output = Result<AggregatedExpirationDateSignatureResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn global_coin_indices_signatures<'life0, 'async_trait>( &'life0 self, epoch_id: Option<EpochId>, ) -> Pin<Box<dyn Future<Output = Result<AggregatedCoinIndicesSignatureResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn master_verification_key<'life0, 'async_trait>( &'life0 self, epoch_id: Option<EpochId>, ) -> Pin<Box<dyn Future<Output = Result<VerificationKeyResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn force_refresh_describe_cache<'life0, 'life1, 'async_trait>( &'life0 self, request: &'life1 NodeRefreshBody, ) -> Pin<Box<dyn Future<Output = Result<(), NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait { ... } fn issued_ticketbooks_for<'life0, 'async_trait>( &'life0 self, expiration_date: Date, ) -> Pin<Box<dyn Future<Output = Result<IssuedTicketbooksForResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn issued_ticketbooks_for_count<'life0, 'async_trait>( &'life0 self, expiration_date: Date, ) -> Pin<Box<dyn Future<Output = Result<IssuedTicketbooksForCountResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn issued_ticketbooks_challenge_commitment<'life0, 'life1, 'async_trait>( &'life0 self, request: &'life1 IssuedTicketbooksChallengeCommitmentRequest, ) -> Pin<Box<dyn Future<Output = Result<IssuedTicketbooksChallengeCommitmentResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait { ... } fn issued_ticketbooks_data<'life0, 'life1, 'async_trait>( &'life0 self, request: &'life1 IssuedTicketbooksDataRequest, ) -> Pin<Box<dyn Future<Output = Result<IssuedTicketbooksDataResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait { ... } fn nodes_by_addresses<'life0, 'async_trait>( &'life0 self, addresses: Vec<IpAddr>, ) -> Pin<Box<dyn Future<Output = Result<NodesByAddressesResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_network_details<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<NymNetworkDetailsResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_chain_status<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<ChainStatusResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_chain_blocks_status<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<ChainBlocksStatusResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_signer_status<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<EcashSignerStatusResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_signer_information<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<SignerInformationResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_key_rotation_info<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<KeyRotationInfoResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_all_expanded_nodes<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<SemiSkimmedNodesWithMetadata, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn get_known_network_monitor<'life0, 'life1, 'async_trait>( &'life0 self, identity_key: IdentityKeyRef<'life1>, ) -> Pin<Box<dyn Future<Output = Result<KnownNetworkMonitorResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait { ... } fn submit_stress_testing_results<'life0, 'life1, 'async_trait>( &'life0 self, request: &'life1 StressTestBatchSubmission, ) -> Pin<Box<dyn Future<Output = Result<StressTestBatchSubmissionResponse, NymAPIError>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait { ... }
}

Required Methods

fn api_url(&self) -> &Url

Get the current API URL being used by the client

fn change_base_urls(&mut self, urls: Vec<Url>)

Method to change the base API URLs being used by the client

Provided Methods

fn health<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<ApiHealthResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn build_information<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<BinaryBuildInformationOwned, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_node_performance_history<'life0, 'async_trait>( &'life0 self, node_id: NodeId, page: Option<u32>, per_page: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<PerformanceHistoryResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_nodes_described<'life0, 'async_trait>( &'life0 self, page: Option<u32>, per_page: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<PaginatedResponse<NymNodeDescriptionV1>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

👎Deprecated:

use .get_nodes_described_v2 instead

fn get_nodes_described_v2<'life0, 'async_trait>( &'life0 self, page: Option<u32>, per_page: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<PaginatedResponse<NymNodeDescriptionV2>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_current_rewarded_set<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<RewardedSetResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_all_basic_nodes_with_metadata<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<SkimmedNodesWithMetadata, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_all_basic_active_mixing_assigned_nodes_with_metadata<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<SkimmedNodesWithMetadata, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_all_basic_entry_assigned_nodes_with_metadata<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<SkimmedNodesWithMetadata, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_all_described_nodes<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<Vec<NymNodeDescriptionV1>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

👎Deprecated:

use .get_all_described_nodes_v2 instead

fn get_all_described_nodes_v2<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<Vec<NymNodeDescriptionV2>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_nym_nodes<'life0, 'async_trait>( &'life0 self, page: Option<u32>, per_page: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<PaginatedResponse<NymNodeDetails>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_all_bonded_nym_nodes<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<Vec<NymNodeDetails>, ValidatorClientError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_node_families<'life0, 'async_trait>( &'life0 self, page: Option<u32>, per_page: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<PaginatedResponse<NodeFamily>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_all_node_families<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<Vec<NodeFamily>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_basic_mixnodes<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<CachedNodesResponse<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

👎Deprecated
fn get_basic_gateways<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<CachedNodesResponse<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

👎Deprecated
fn get_rewarded_set<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<RewardedSetResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_basic_entry_assigned_nodes<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV1<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

👎Deprecated:

use get_basic_entry_assigned_nodes_v2

retrieve basic information for nodes are capable of operating as an entry gateway this includes legacy gateways and nym-nodes

fn get_basic_entry_assigned_nodes_v2<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV2<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

retrieve basic information for nodes are capable of operating as an entry gateway this includes legacy gateways and nym-nodes

fn get_basic_active_mixing_assigned_nodes<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV1<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

👎Deprecated:

use get_basic_active_mixing_assigned_nodes_v2

retrieve basic information for nodes that got assigned ‘mixing’ node in this epoch this includes legacy mixnodes and nym-nodes

fn get_basic_active_mixing_assigned_nodes_v2<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV2<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

retrieve basic information for nodes that got assigned ‘mixing’ node in this epoch this includes legacy mixnodes and nym-nodes

fn get_basic_mixing_capable_nodes<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV1<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

👎Deprecated:

use get_basic_mixing_capable_nodes_v2

retrieve basic information for nodes that got assigned ‘mixing’ node in this epoch this includes legacy mixnodes and nym-nodes

fn get_basic_mixing_capable_nodes_v2<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV2<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

retrieve basic information for nodes that got assigned ‘mixing’ node in this epoch this includes legacy mixnodes and nym-nodes

fn get_basic_nodes<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV1<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

👎Deprecated:

use get_basic_nodes_v2

fn get_basic_nodes_v2<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV2<SkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_expanded_nodes<'life0, 'async_trait>( &'life0 self, no_legacy: bool, page: Option<u32>, per_page: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV2<SemiSkimmedNodeV1>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_expanded_nodes_v3<'life0, 'async_trait>( &'life0 self, use_bincode: bool, ) -> Pin<Box<dyn Future<Output = Result<PaginatedCachedNodesResponseV2<SemiSkimmedNodeV3>, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_mixnode_report<'life0, 'async_trait>( &'life0 self, mix_id: NodeId, ) -> Pin<Box<dyn Future<Output = Result<MixnodeStatusReportResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

👎Deprecated
fn get_gateway_report<'life0, 'life1, 'async_trait>( &'life0 self, identity: IdentityKeyRef<'life1>, ) -> Pin<Box<dyn Future<Output = Result<GatewayStatusReportResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

👎Deprecated
fn get_mixnode_history<'life0, 'async_trait>( &'life0 self, mix_id: NodeId, ) -> Pin<Box<dyn Future<Output = Result<MixnodeUptimeHistoryResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

👎Deprecated
fn get_gateway_history<'life0, 'life1, 'async_trait>( &'life0 self, identity: IdentityKeyRef<'life1>, ) -> Pin<Box<dyn Future<Output = Result<GatewayUptimeHistoryResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

👎Deprecated
fn get_gateway_core_status_count<'life0, 'life1, 'async_trait>( &'life0 self, identity: IdentityKeyRef<'life1>, since: Option<i64>, ) -> Pin<Box<dyn Future<Output = Result<GatewayCoreStatusResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

👎Deprecated
fn get_mixnode_core_status_count<'life0, 'async_trait>( &'life0 self, mix_id: NodeId, since: Option<i64>, ) -> Pin<Box<dyn Future<Output = Result<MixnodeCoreStatusResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

👎Deprecated
fn get_current_node_performance<'life0, 'async_trait>( &'life0 self, node_id: NodeId, ) -> Pin<Box<dyn Future<Output = Result<NodePerformanceResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_node_annotation<'life0, 'async_trait>( &'life0 self, node_id: NodeId, ) -> Pin<Box<dyn Future<Output = Result<AnnotationResponseV1, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_node_annotation_v2<'life0, 'async_trait>( &'life0 self, node_id: NodeId, ) -> Pin<Box<dyn Future<Output = Result<AnnotationResponseV2, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_mixnode_avg_uptime<'life0, 'async_trait>( &'life0 self, mix_id: NodeId, ) -> Pin<Box<dyn Future<Output = Result<UptimeResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

👎Deprecated
fn blind_sign<'life0, 'life1, 'async_trait>( &'life0 self, request_body: &'life1 BlindSignRequestBody, ) -> Pin<Box<dyn Future<Output = Result<BlindedSignatureResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn verify_ecash_ticket<'life0, 'life1, 'async_trait>( &'life0 self, request_body: &'life1 VerifyEcashTicketBody, ) -> Pin<Box<dyn Future<Output = Result<EcashTicketVerificationResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn batch_redeem_ecash_tickets<'life0, 'life1, 'async_trait>( &'life0 self, request_body: &'life1 BatchRedeemTicketsBody, ) -> Pin<Box<dyn Future<Output = Result<EcashBatchTicketRedemptionResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn partial_expiration_date_signatures<'life0, 'async_trait>( &'life0 self, expiration_date: Option<Date>, epoch_id: Option<EpochId>, ) -> Pin<Box<dyn Future<Output = Result<PartialExpirationDateSignatureResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn partial_coin_indices_signatures<'life0, 'async_trait>( &'life0 self, epoch_id: Option<EpochId>, ) -> Pin<Box<dyn Future<Output = Result<PartialCoinIndicesSignatureResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn global_expiration_date_signatures<'life0, 'async_trait>( &'life0 self, expiration_date: Option<Date>, epoch_id: Option<EpochId>, ) -> Pin<Box<dyn Future<Output = Result<AggregatedExpirationDateSignatureResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn global_coin_indices_signatures<'life0, 'async_trait>( &'life0 self, epoch_id: Option<EpochId>, ) -> Pin<Box<dyn Future<Output = Result<AggregatedCoinIndicesSignatureResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn master_verification_key<'life0, 'async_trait>( &'life0 self, epoch_id: Option<EpochId>, ) -> Pin<Box<dyn Future<Output = Result<VerificationKeyResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn force_refresh_describe_cache<'life0, 'life1, 'async_trait>( &'life0 self, request: &'life1 NodeRefreshBody, ) -> Pin<Box<dyn Future<Output = Result<(), NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn issued_ticketbooks_for<'life0, 'async_trait>( &'life0 self, expiration_date: Date, ) -> Pin<Box<dyn Future<Output = Result<IssuedTicketbooksForResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn issued_ticketbooks_for_count<'life0, 'async_trait>( &'life0 self, expiration_date: Date, ) -> Pin<Box<dyn Future<Output = Result<IssuedTicketbooksForCountResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn issued_ticketbooks_challenge_commitment<'life0, 'life1, 'async_trait>( &'life0 self, request: &'life1 IssuedTicketbooksChallengeCommitmentRequest, ) -> Pin<Box<dyn Future<Output = Result<IssuedTicketbooksChallengeCommitmentResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn issued_ticketbooks_data<'life0, 'life1, 'async_trait>( &'life0 self, request: &'life1 IssuedTicketbooksDataRequest, ) -> Pin<Box<dyn Future<Output = Result<IssuedTicketbooksDataResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

fn nodes_by_addresses<'life0, 'async_trait>( &'life0 self, addresses: Vec<IpAddr>, ) -> Pin<Box<dyn Future<Output = Result<NodesByAddressesResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_network_details<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<NymNetworkDetailsResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_chain_status<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<ChainStatusResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_chain_blocks_status<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<ChainBlocksStatusResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_signer_status<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<EcashSignerStatusResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_signer_information<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<SignerInformationResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_key_rotation_info<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<KeyRotationInfoResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

fn get_all_expanded_nodes<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = Result<SemiSkimmedNodesWithMetadata, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Retrieve expanded information for all bonded nodes on the network

fn get_known_network_monitor<'life0, 'life1, 'async_trait>( &'life0 self, identity_key: IdentityKeyRef<'life1>, ) -> Pin<Box<dyn Future<Output = Result<KnownNetworkMonitorResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Queries the nym-api for whether a particular ed25519 identity key is currently recognised as an authorised network monitor permitted to submit stress testing results.

identity_key is expected to be the base58-encoded form of the ed25519 public key.

fn submit_stress_testing_results<'life0, 'life1, 'async_trait>( &'life0 self, request: &'life1 StressTestBatchSubmission, ) -> Pin<Box<dyn Future<Output = Result<StressTestBatchSubmissionResponse, NymAPIError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Submit a signed batch of stress-testing results to nym-api on behalf of a network monitor orchestrator.

The caller is expected to have produced request via StressTestBatchSubmissionContent::new(...) and signed it with the orchestrator’s ed25519 key; nym-api will reject submissions that are stale, replayed, unauthorised, or whose signature fails to verify.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl NymApiClientExt for Client

Source

fn api_url(&self) -> &Url

Source

fn change_base_urls(&mut self, urls: Vec<Url>)

Implementors