pub struct AbsoluteTxPosition {
pub block_height: u64,
pub tx_index: u64,
}Expand description
AbsoluteTxPosition is a unique transaction position that allows for global ordering of transactions.
Fields
block_height: u64BlockHeight is the block the contract was created at
tx_index: u64TxIndex is a monotonic counter within the block (actual transaction index, or gas consumed)