pub struct MsgUpdateAdmin {
pub sender: AccountId,
pub new_admin: AccountId,
pub contract: AccountId,
}Expand description
MsgUpdateAdmin sets a new admin for a smart contract
Fields
sender: AccountIdSender is the that actor that signed the messages
new_admin: AccountIdNewAdmin address to be set
contract: AccountIdContract is the address of the smart contract