pub struct Event {
pub kind: String,
pub attributes: Vec<EventAttribute>,
}Expand description
An event that occurred while processing a request.
Application developers can attach additional information to
BeginBlock,
EndBlock,
CheckTx, and
DeliverTx responses. Later, transactions may
be queried using these events.
Fields
kind: StringThe kind of event.
Tendermint calls this the type, but we use kind to avoid confusion
with Rust types and follow Rust conventions.
attributes: Vec<EventAttribute>A list of EventAttributes describing the event.
Implementations
Sourceimpl Event
impl Event
Sourcepub fn new<K, I>(kind: K, attributes: I) -> Event
pub fn new<K, I>(kind: K, attributes: I) -> Event
Construct an event from generic data.
The From impls on EventAttribute and the EventAttributeIndexExt
trait allow ergonomic event construction, as in this example:
use tendermint::abci::{Event, EventAttributeIndexExt};
let event = Event::new(
"app",
[
("key1", "value1").index(),
("key2", "value2").index(),
("key3", "value3").no_index(), // will not be indexed
],
);Sourcepub fn eq_ignoring_index(&self, other: &Event) -> bool
pub fn eq_ignoring_index(&self, other: &Event) -> bool
Checks whether &self is equal to other, ignoring the index field on any attributes.
Sourcepub fn hash_ignoring_index<H>(&self, state: &mut H)where
H: Hasher,
pub fn hash_ignoring_index<H>(&self, state: &mut H)where
H: Hasher,
A variant of core::hash::Hash::hash that ignores the index field on any attributes.