pub struct ExecTxResult {
pub code: Code,
pub data: Bytes,
pub log: String,
pub info: String,
pub gas_wanted: i64,
pub gas_used: i64,
pub events: Vec<Event>,
pub codespace: String,
}Expand description
Results of executing one individual transaction.
This structure is equivalent to response::DeliverTx which will be
deprecated and removed.
Fields
code: CodeThe response code.
This code should be Ok only if the transaction is fully valid. However,
invalid transactions included in a block will still be executed against
the application state.
data: BytesResult bytes, if any.
log: StringThe output of the application’s logger.
May be non-deterministic.
info: StringAdditional information.
May be non-deterministic.
gas_wanted: i64Amount of gas requested for the transaction.
gas_used: i64Amount of gas consumed by the transaction.
events: Vec<Event>Events that occurred while executing the transaction.
codespace: StringThe namespace for the code.