NyxdClient

Struct NyxdClient 

pub struct NyxdClient<C, S = NoSigner> { /* private fields */ }

Implementations

Source

impl NyxdClient<HttpClient>

Source

impl NyxdClient<ReqwestRpcClient>

Source

impl<C> NyxdClient<C>

pub fn new(config: Config, client: C) -> Self

Source

impl NyxdClient<HttpClient, DirectSecp256k1HdWallet>

Source

impl NyxdClient<ReqwestRpcClient, DirectSecp256k1HdWallet>

Source

impl<C, S> NyxdClient<C, S>
where S: OfflineSigner,

pub fn connect_with_signer( config: Config, client: C, signer: S, ) -> NyxdClient<C, S>

Source

impl<S> NyxdClient<HttpClient, S>

pub fn change_endpoint<U>(&mut self, new_endpoint: U) -> Result<(), NyxdError>

Source

impl<C, S> NyxdClient<C, S>

pub fn new_signing(config: Config, client: C, signer: S) -> Self
where S: OfflineSigner,

pub fn clone_query_client(&self) -> NyxdClient<C>
where C: Clone,

pub fn current_config(&self) -> &Config

pub fn current_chain_details(&self) -> &ChainDetails

pub fn set_mixnet_contract_address(&mut self, address: AccountId)

pub fn set_vesting_contract_address(&mut self, address: AccountId)

pub fn set_ecash_contract_address(&mut self, address: AccountId)

pub fn set_multisig_contract_address(&mut self, address: AccountId)

pub fn set_node_families_contract_address(&mut self, address: AccountId)

pub fn set_simulated_gas_multiplier(&mut self, multiplier: f32)

pub fn get_nym_contracts(&self) -> TypedNymContracts

pub fn get_chain_details(&self) -> ChainDetails

Source

impl<C, S> NyxdClient<C, S>
where C: TendermintRpcClient + Send + Sync, S: Send + Sync,

pub async fn get_account_public_key( &self, address: &AccountId, ) -> Result<Option<PublicKey>, NyxdError>

pub async fn get_current_block_timestamp( &self, ) -> Result<TendermintTime, NyxdError>

pub async fn get_block_timestamp( &self, height: Option<u32>, ) -> Result<TendermintTime, NyxdError>

pub async fn get_block( &self, height: Option<u32>, ) -> Result<BlockResponse, NyxdError>

pub async fn get_current_block_height(&self) -> Result<Height, NyxdError>

pub async fn get_block_hash(&self, height: u32) -> Result<Hash, NyxdError>

Obtains the hash of a block specified by the provided height.

Arguments
  • height: height of the block for which we want to obtain the hash.
pub async fn try_get_cw2_contract_version( &self, contract_address: &AccountId, ) -> Option<ContractVersion>

pub async fn try_get_contract_build_information( &self, contract_address: &AccountId, ) -> Option<ContractBuildInformation>

Source

impl<C, S> NyxdClient<C, S>

pub fn signing_account(&self) -> Result<&AccountData, NyxdError>

pub fn address(&self) -> AccountId

pub fn mix_coin(&self, amount: u128) -> Coin

pub fn mix_coins(&self, amount: u128) -> Vec<Coin>

pub fn cw_address(&self) -> Addr

pub async fn account_sequence(&self) -> Result<SequenceResponse, NyxdError>

pub fn wrap_contract_execute_message<M>( &self, contract_address: &AccountId, msg: &M, funds: Vec<Coin>, ) -> Result<MsgExecuteContract, NyxdError>
where M: ?Sized + Serialize,

pub async fn simulate<I, M>( &self, messages: I, memo: impl Into<String> + Send + 'static, ) -> Result<SimulateResponse, NyxdError>
where I: IntoIterator<Item = M> + Send, M: Msg,

pub async fn send( &self, recipient: &AccountId, amount: Vec<Coin>, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<TxResponse, NyxdError>

Send funds from one address to another

pub async fn send_multiple( &self, msgs: Vec<(AccountId, Vec<Coin>)>, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<TxResponse, NyxdError>

Send funds from one address to multiple others

pub async fn grant_allowance( &self, grantee: &AccountId, spend_limit: Vec<Coin>, expiration: Option<SystemTime>, allowed_messages: Vec<String>, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<TxResponse, NyxdError>

Grant a fee allowance from one address to another

pub async fn revoke_allowance( &self, grantee: &AccountId, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<TxResponse, NyxdError>

Revoke a fee allowance from one address to another

pub async fn execute<M>( &self, contract_address: &AccountId, msg: &M, fee: Option<Fee>, memo: impl Into<String> + Send + 'static, funds: Vec<Coin>, ) -> Result<ExecuteResult, NyxdError>
where M: ?Sized + Serialize + Sync,

pub async fn execute_multiple<I, M>( &self, contract_address: &AccountId, msgs: I, fee: Option<Fee>, memo: impl Into<String> + Send + 'static, ) -> Result<ExecuteResult, NyxdError>
where I: IntoIterator<Item = (M, Vec<Coin>)> + Send, M: Serialize,

pub async fn upload( &self, wasm_code: Vec<u8>, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<UploadResult, NyxdError>

pub async fn instantiate<M>( &self, code_id: ContractCodeId, msg: &M, label: String, memo: impl Into<String> + Send + 'static, options: Option<InstantiateOptions>, fee: Option<Fee>, ) -> Result<InstantiateResult, NyxdError>
where M: ?Sized + Serialize + Sync,

pub async fn update_admin( &self, contract_address: &AccountId, new_admin: &AccountId, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<ChangeAdminResult, NyxdError>

pub async fn clear_admin( &self, contract_address: &AccountId, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<ChangeAdminResult, NyxdError>

pub async fn migrate<M>( &self, contract_address: &AccountId, code_id: ContractCodeId, msg: &M, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<MigrateResult, NyxdError>
where M: ?Sized + Serialize + Sync,