PageRequest

Struct PageRequest 

pub struct PageRequest {
    pub key: Vec<u8>,
    pub offset: u64,
    pub limit: u64,
    pub count_total: bool,
    pub reverse: bool,
}
PageRequest is to be embedded in gRPC request messages for efficient pagination.

Fields

key: Vec<u8>

key is a value returned in PageResponse.next_key to begin querying the next page most efficiently. Only one of offset or key should be set.

offset: u64

offset is a numeric offset that can be used when key is unavailable. It is less efficient than using key. Only one of offset or key should be set.

limit: u64

limit is the total number of results to be returned in the result page. If left empty it will default to a value to be set by each app.

count_total: bool

count_total is set to true to indicate that the result set should include a count of the total number of items available for pagination in UIs. count_total is only respected when offset is used. It is ignored when key is set.

reverse: bool

reverse is set to true if results are to be returned in the descending order.

Since: cosmos-sdk 0.43