pub struct PageResponse {
pub next_key: Vec<u8>,
pub total: u64,
}Expand description
PageResponse is to be embedded in gRPC response messages where the corresponding request message has used PageRequest.
Fields
next_key: Vec<u8>next_key is the key to be passed to PageRequest.key to query the next page most efficiently. It will be empty if there are no more results.
total: u64total is total number of results available if PageRequest.count_total was set, its value is undefined otherwise