pub trait SimpleRequest<S = Dialect>: Request<S>where
S: Dialect,{
type Output: From<Self::Response>;
}Expand description
Simple JSON-RPC requests which correlate with a single response from the remote endpoint.
An example of a request which is not simple would be the event subscription
request, which, on success, returns a Subscription and not just a
simple, singular response.
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".