pub struct AuthInfo {
pub signer_infos: Vec<SignerInfo>,
pub fee: Fee,
}Expand description
AuthInfo describes the fee and signer modes that are used to sign a transaction.
Fields
signer_infos: Vec<SignerInfo>Defines the signing modes for the required signers.
The number and order of elements must match the required signers from transaction
Body’s messages. The first element is the primary signer and the one
which pays the Fee.
fee: FeeFee and gas limit for the transaction.
The first signer is the primary signer and the one which pays the fee. The fee can be calculated based on the cost of evaluating the body and doing signature verification of the signers. This can be estimated via simulation.
Implementations