Body

Struct Body 

pub struct Body {
    pub messages: Vec<Any>,
    pub memo: String,
    pub timeout_height: Height,
    pub extension_options: Vec<Any>,
    pub non_critical_extension_options: Vec<Any>,
}
Body of a transaction that all signers sign over.

This type is known as TxBody in the Golang cosmos-sdk.

Fields

messages: Vec<Any>

messages is a list of messages to be executed. The required signers of those messages define the number and order of elements in AuthInfo’s signer_infos and Tx’s signatures. Each required signer address is added to the list only the first time it occurs.

By convention, the first required signer (usually from the first message) is referred to as the primary signer and pays the fee for the whole transaction.

memo: String

memo is any arbitrary memo to be added to the transaction.

timeout_height: Height

timeout is the block height after which this transaction will not be processed by the chain

extension_options: Vec<Any>

extension_options are arbitrary options that can be added by chains when the default options are not sufficient. If any of these are present and can’t be handled, the transaction will be rejected

non_critical_extension_options: Vec<Any>

extension_options are arbitrary options that can be added by chains when the default options are not sufficient. If any of these are present and can’t be handled, they will be ignored

Implementations

Source

impl Body

pub fn new<I>( messages: I, memo: impl Into<String>, timeout_height: impl Into<Height>, ) -> Body
where I: IntoIterator<Item = Any>,

Create a new Body from the given messages, memo, and timeout height.

pub fn into_proto(self) -> TxBody

Convert the body to a Protocol Buffers representation.

pub fn into_bytes(self) -> Result<Vec<u8>, Report>

Encode this type using Protocol Buffers.