pub struct SignDoc {
pub body_bytes: Vec<u8>,
pub auth_info_bytes: Vec<u8>,
pub chain_id: String,
pub account_number: u64,
}Expand description
SignDoc is the type used for generating sign bytes for SIGN_MODE_DIRECT.
Fields
body_bytes: Vec<u8>body_bytes is protobuf serialization of a transaction Body that matches the
representation in a Raw transaction.
auth_info_bytes: Vec<u8>auth_info_bytes is a protobuf serialization of an AuthInfo that matches the
representation in a Raw.
chain_id: Stringchain_id is the unique identifier of the chain this transaction targets.
It prevents signed transactions from being used on another chain by an attacker.
account_number: u64account_number is the account number of the account in state
Implementations