pub trait TendermintRpcClient {
Show 28 methods
// Required method
fn perform<'life0, 'async_trait, R>(
&'life0 self,
request: R,
) -> Pin<Box<dyn Future<Output = Result<R::Output, Error>> + Send + 'async_trait>>
where R: SimpleRequest + 'async_trait,
Self: 'async_trait,
'life0: 'async_trait;
// Provided methods
fn abci_info<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Info, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn abci_query<'life0, 'async_trait, V>(
&'life0 self,
path: Option<String>,
data: V,
height: Option<Height>,
prove: bool,
) -> Pin<Box<dyn Future<Output = Result<AbciQuery, Error>> + Send + 'async_trait>>
where V: Into<Vec<u8>> + Send + 'async_trait,
Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn block<'life0, 'async_trait, H>(
&'life0 self,
height: H,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where H: Into<Height> + Send + 'async_trait,
Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn block_by_hash<'life0, 'async_trait>(
&'life0 self,
hash: Hash,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn latest_block<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn header<'life0, 'async_trait, H>(
&'life0 self,
height: H,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where H: Into<Height> + Send + 'async_trait,
Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn header_by_hash<'life0, 'async_trait>(
&'life0 self,
hash: Hash,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn block_results<'life0, 'async_trait, H>(
&'life0 self,
height: H,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where H: Into<Height> + Send + 'async_trait,
Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn latest_block_results<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn block_search<'life0, 'async_trait>(
&'life0 self,
query: Query,
page: u32,
per_page: u8,
order: Order,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn blockchain<'life0, 'async_trait, H>(
&'life0 self,
min: H,
max: H,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where H: Into<Height> + Send + 'async_trait,
Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn broadcast_tx_async<'life0, 'async_trait, T>(
&'life0 self,
tx: T,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where T: Into<Vec<u8>> + Send + 'async_trait,
Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn broadcast_tx_sync<'life0, 'async_trait, T>(
&'life0 self,
tx: T,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where T: Into<Vec<u8>> + Send + 'async_trait,
Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn broadcast_tx_commit<'life0, 'async_trait, T>(
&'life0 self,
tx: T,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where T: Into<Vec<u8>> + Send + 'async_trait,
Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn commit<'life0, 'async_trait, H>(
&'life0 self,
height: H,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where H: Into<Height> + Send + 'async_trait,
Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn consensus_params<'life0, 'async_trait, H>(
&'life0 self,
height: H,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where H: Into<Height> + Send + 'async_trait,
Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn consensus_state<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn validators<'life0, 'async_trait, H>(
&'life0 self,
height: H,
paging: Paging,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where H: Into<Height> + Send + 'async_trait,
Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn latest_consensus_params<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn latest_commit<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn health<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn genesis<'life0, 'async_trait, AppState>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Genesis<AppState>, Error>> + Send + 'async_trait>>
where AppState: Debug + Serialize + DeserializeOwned + Send + 'async_trait,
Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn net_info<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn status<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn broadcast_evidence<'life0, 'async_trait>(
&'life0 self,
e: Evidence,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn tx<'life0, 'async_trait>(
&'life0 self,
hash: Hash,
prove: bool,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
fn tx_search<'life0, 'async_trait>(
&'life0 self,
query: Query,
prove: bool,
page: u32,
per_page: u8,
order: Order,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
where Self: Sync + 'async_trait,
'life0: 'async_trait { ... }
}Required Methods
Sourcefn perform<'life0, 'async_trait, R>(
&'life0 self,
request: R,
) -> Pin<Box<dyn Future<Output = Result<R::Output, Error>> + Send + 'async_trait>>where
R: SimpleRequest + 'async_trait,
Self: 'async_trait,
'life0: 'async_trait,
fn perform<'life0, 'async_trait, R>(
&'life0 self,
request: R,
) -> Pin<Box<dyn Future<Output = Result<R::Output, Error>> + Send + 'async_trait>>where
R: SimpleRequest + 'async_trait,
Self: 'async_trait,
'life0: 'async_trait,
Perform a request against the RPC endpoint.
This method is used by the default implementations of specific endpoint methods. The latest protocol dialect is assumed to be invoked.
Provided Methods
Sourcefn abci_info<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Info, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn abci_info<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Info, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
/abci_info: get information about the ABCI application.
Sourcefn abci_query<'life0, 'async_trait, V>(
&'life0 self,
path: Option<String>,
data: V,
height: Option<Height>,
prove: bool,
) -> Pin<Box<dyn Future<Output = Result<AbciQuery, Error>> + Send + 'async_trait>>
fn abci_query<'life0, 'async_trait, V>( &'life0 self, path: Option<String>, data: V, height: Option<Height>, prove: bool, ) -> Pin<Box<dyn Future<Output = Result<AbciQuery, Error>> + Send + 'async_trait>>
/abci_query: query the ABCI application
Sourcefn block<'life0, 'async_trait, H>(
&'life0 self,
height: H,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
fn block<'life0, 'async_trait, H>( &'life0 self, height: H, ) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
/block: get block at a given height.
Sourcefn block_by_hash<'life0, 'async_trait>(
&'life0 self,
hash: Hash,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn block_by_hash<'life0, 'async_trait>(
&'life0 self,
hash: Hash,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
/block_by_hash: get block by hash.
Sourcefn latest_block<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn latest_block<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
/block: get the latest block.
Sourcefn header<'life0, 'async_trait, H>(
&'life0 self,
height: H,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
fn header<'life0, 'async_trait, H>( &'life0 self, height: H, ) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
/header: get block header at a given height.
Sourcefn header_by_hash<'life0, 'async_trait>(
&'life0 self,
hash: Hash,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn header_by_hash<'life0, 'async_trait>(
&'life0 self,
hash: Hash,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
/header_by_hash: get block by hash.
Sourcefn block_results<'life0, 'async_trait, H>(
&'life0 self,
height: H,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
fn block_results<'life0, 'async_trait, H>( &'life0 self, height: H, ) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
/block_results: get ABCI results for a block at a particular height.
Sourcefn latest_block_results<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn latest_block_results<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
/block_results: get ABCI results for the latest block.
Sourcefn block_search<'life0, 'async_trait>(
&'life0 self,
query: Query,
page: u32,
per_page: u8,
order: Order,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn block_search<'life0, 'async_trait>(
&'life0 self,
query: Query,
page: u32,
per_page: u8,
order: Order,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
/block_search: search for blocks by BeginBlock and EndBlock events.
Sourcefn blockchain<'life0, 'async_trait, H>(
&'life0 self,
min: H,
max: H,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
fn blockchain<'life0, 'async_trait, H>( &'life0 self, min: H, max: H, ) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
/blockchain: get block headers for min <= height <= max.
Block headers are returned in descending order (highest first).
Returns at most 20 items.
Sourcefn broadcast_tx_async<'life0, 'async_trait, T>(
&'life0 self,
tx: T,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
fn broadcast_tx_async<'life0, 'async_trait, T>( &'life0 self, tx: T, ) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
/broadcast_tx_async: broadcast a transaction, returning immediately.
Sourcefn broadcast_tx_sync<'life0, 'async_trait, T>(
&'life0 self,
tx: T,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
fn broadcast_tx_sync<'life0, 'async_trait, T>( &'life0 self, tx: T, ) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
/broadcast_tx_sync: broadcast a transaction, returning the response
from CheckTx.
Sourcefn broadcast_tx_commit<'life0, 'async_trait, T>(
&'life0 self,
tx: T,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
fn broadcast_tx_commit<'life0, 'async_trait, T>( &'life0 self, tx: T, ) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
/broadcast_tx_commit: broadcast a transaction, returning the response
from DeliverTx.
Sourcefn commit<'life0, 'async_trait, H>(
&'life0 self,
height: H,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
fn commit<'life0, 'async_trait, H>( &'life0 self, height: H, ) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
/commit: get block commit at a given height.
Sourcefn consensus_params<'life0, 'async_trait, H>(
&'life0 self,
height: H,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
fn consensus_params<'life0, 'async_trait, H>( &'life0 self, height: H, ) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
/consensus_params: get current consensus parameters at the specified
height.
Sourcefn consensus_state<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn consensus_state<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
/consensus_state: get current consensus state
Sourcefn validators<'life0, 'async_trait, H>(
&'life0 self,
height: H,
paging: Paging,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
fn validators<'life0, 'async_trait, H>( &'life0 self, height: H, paging: Paging, ) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>
/validators: get validators a given height.
Sourcefn latest_consensus_params<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn latest_consensus_params<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
/consensus_params: get the latest consensus parameters.
Sourcefn latest_commit<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn latest_commit<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
/commit: get the latest block commit
Sourcefn health<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn health<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
/health: get node health.
Returns empty result (200 OK) on success, no response in case of an error.
Sourcefn genesis<'life0, 'async_trait, AppState>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Genesis<AppState>, Error>> + Send + 'async_trait>>where
AppState: Debug + Serialize + DeserializeOwned + Send + 'async_trait,
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn genesis<'life0, 'async_trait, AppState>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Genesis<AppState>, Error>> + Send + 'async_trait>>where
AppState: Debug + Serialize + DeserializeOwned + Send + 'async_trait,
Self: Sync + 'async_trait,
'life0: 'async_trait,
/genesis: get genesis file.
Sourcefn net_info<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn net_info<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
/net_info: obtain information about P2P and other network connections.
Sourcefn status<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn status<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
/status: get Tendermint status including node info, pubkey, latest
block hash, app hash, block height and time.
Sourcefn broadcast_evidence<'life0, 'async_trait>(
&'life0 self,
e: Evidence,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn broadcast_evidence<'life0, 'async_trait>(
&'life0 self,
e: Evidence,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
/broadcast_evidence: broadcast an evidence.
Sourcefn tx<'life0, 'async_trait>(
&'life0 self,
hash: Hash,
prove: bool,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn tx<'life0, 'async_trait>(
&'life0 self,
hash: Hash,
prove: bool,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
/tx: find transaction by hash.
Sourcefn tx_search<'life0, 'async_trait>(
&'life0 self,
query: Query,
prove: bool,
page: u32,
per_page: u8,
order: Order,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
fn tx_search<'life0, 'async_trait>(
&'life0 self,
query: Query,
prove: bool,
page: u32,
per_page: u8,
order: Order,
) -> Pin<Box<dyn Future<Output = Result<Response, Error>> + Send + 'async_trait>>where
Self: Sync + 'async_trait,
'life0: 'async_trait,
/tx_search: search for transactions with their results.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".