pub struct Deprecated<T> {
pub deprecated: bool,
pub response: T,
}Fields
deprecated: boolresponse: TTrait Implementations
Sourceimpl<'de, T> Deserialize<'de> for Deprecated<T>where
T: Deserialize<'de>,
impl<'de, T> Deserialize<'de> for Deprecated<T>where
T: Deserialize<'de>,
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Deprecated<T>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Deprecated<T>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<T> From<T> for Deprecated<T>
impl<T> From<T> for Deprecated<T>
Sourcefn from(response: T) -> Deprecated<T>
fn from(response: T) -> Deprecated<T>
Converts to this type from the input type.
Sourceimpl<T> JsonSchema for Deprecated<T>where
T: JsonSchema,
impl<T> JsonSchema for Deprecated<T>where
T: JsonSchema,
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<T> Serialize for Deprecated<T>where
T: Serialize,
impl<T> Serialize for Deprecated<T>where
T: Serialize,
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more