pub struct MsgStoreCode {
pub sender: AccountId,
pub wasm_byte_code: Vec<u8>,
pub instantiate_permission: Option<AccessConfig>,
}Expand description
MsgStoreCode submit Wasm code to the system
Fields
sender: AccountIdSender is the that actor that signed the messages
wasm_byte_code: Vec<u8>WASMByteCode can be raw or gzip compressed
instantiate_permission: Option<AccessConfig>InstantiatePermission access control to apply on contract creation, optional