pub struct NyxdClient<C, S = NoSigner> { /* private fields */ }Implementations
Sourceimpl NyxdClient<HttpClient>
impl NyxdClient<HttpClient>
pub fn connect<U>( config: Config, endpoint: U, ) -> Result<QueryHttpRpcNyxdClient, NyxdError>
pub fn connect_with_network_details<U>( endpoint: U, network_details: NymNetworkDetails, ) -> Result<QueryHttpRpcNyxdClient, NyxdError>
pub fn connect_to_default_env<U>( endpoint: U, ) -> Result<QueryHttpRpcNyxdClient, NyxdError>
Sourceimpl NyxdClient<ReqwestRpcClient>
impl NyxdClient<ReqwestRpcClient>
pub fn connect_reqwest( config: Config, endpoint: Url, ) -> Result<QueryReqwestRpcNyxdClient, NyxdError>
Sourceimpl NyxdClient<HttpClient, DirectSecp256k1HdWallet>
impl NyxdClient<HttpClient, DirectSecp256k1HdWallet>
pub fn connect_with_mnemonic<U>( config: Config, endpoint: U, mnemonic: Mnemonic, ) -> Result<DirectSigningHttpRpcNyxdClient, NyxdError>
pub fn connect_with_mnemonic_and_network_details<U>( endpoint: U, network_details: NymNetworkDetails, mnemonic: Mnemonic, ) -> Result<DirectSigningHttpRpcNyxdClient, NyxdError>
Sourceimpl NyxdClient<ReqwestRpcClient, DirectSecp256k1HdWallet>
impl NyxdClient<ReqwestRpcClient, DirectSecp256k1HdWallet>
pub fn connect_reqwest_with_mnemonic( config: Config, endpoint: Url, mnemonic: Mnemonic, ) -> DirectSigningReqwestRpcNyxdClient
Sourceimpl<C, S> NyxdClient<C, S>where
S: OfflineSigner,
impl<C, S> NyxdClient<C, S>where
S: OfflineSigner,
pub fn connect_with_signer( config: Config, client: C, signer: S, ) -> NyxdClient<C, S>
Sourceimpl<S> NyxdClient<HttpClient, S>
impl<S> NyxdClient<HttpClient, S>
pub fn change_endpoint<U>(&mut self, new_endpoint: U) -> Result<(), NyxdError>
Sourceimpl<C, S> NyxdClient<C, S>
impl<C, S> NyxdClient<C, S>
pub fn new_signing(config: Config, client: C, signer: S) -> Selfwhere
S: OfflineSigner,
pub fn clone_query_client(&self) -> NyxdClient<C>where
C: Clone,
pub fn current_config(&self) -> &Config
pub fn current_chain_details(&self) -> &ChainDetails
pub fn set_mixnet_contract_address(&mut self, address: AccountId)
pub fn set_vesting_contract_address(&mut self, address: AccountId)
pub fn set_ecash_contract_address(&mut self, address: AccountId)
pub fn set_multisig_contract_address(&mut self, address: AccountId)
pub fn set_node_families_contract_address(&mut self, address: AccountId)
pub fn set_simulated_gas_multiplier(&mut self, multiplier: f32)
pub fn get_nym_contracts(&self) -> TypedNymContracts
pub fn get_chain_details(&self) -> ChainDetails
Sourceimpl<C, S> NyxdClient<C, S>
impl<C, S> NyxdClient<C, S>
pub async fn get_account_public_key( &self, address: &AccountId, ) -> Result<Option<PublicKey>, NyxdError>
pub async fn get_current_block_timestamp( &self, ) -> Result<TendermintTime, NyxdError>
pub async fn get_block_timestamp( &self, height: Option<u32>, ) -> Result<TendermintTime, NyxdError>
pub async fn get_block( &self, height: Option<u32>, ) -> Result<BlockResponse, NyxdError>
pub async fn get_current_block_height(&self) -> Result<Height, NyxdError>
Sourcepub async fn get_block_hash(&self, height: u32) -> Result<Hash, NyxdError>
pub async fn get_block_hash(&self, height: u32) -> Result<Hash, NyxdError>
Obtains the hash of a block specified by the provided height.
Arguments
height: height of the block for which we want to obtain the hash.
pub async fn try_get_cw2_contract_version( &self, contract_address: &AccountId, ) -> Option<ContractVersion>
pub async fn try_get_contract_build_information( &self, contract_address: &AccountId, ) -> Option<ContractBuildInformation>
Sourceimpl<C, S> NyxdClient<C, S>where
C: TendermintRpcClient + Send + Sync,
S: OfflineSigner + Send + Sync,
NyxdError: From<<S as OfflineSigner>::Error>,
impl<C, S> NyxdClient<C, S>where
C: TendermintRpcClient + Send + Sync,
S: OfflineSigner + Send + Sync,
NyxdError: From<<S as OfflineSigner>::Error>,
pub fn signing_account(&self) -> Result<&AccountData, NyxdError>
pub fn address(&self) -> AccountId
pub fn mix_coin(&self, amount: u128) -> Coin
pub fn mix_coins(&self, amount: u128) -> Vec<Coin>
pub fn cw_address(&self) -> Addr
pub async fn account_sequence(&self) -> Result<SequenceResponse, NyxdError>
pub fn wrap_contract_execute_message<M>( &self, contract_address: &AccountId, msg: &M, funds: Vec<Coin>, ) -> Result<MsgExecuteContract, NyxdError>
pub async fn simulate<I, M>( &self, messages: I, memo: impl Into<String> + Send + 'static, ) -> Result<SimulateResponse, NyxdError>
Sourcepub async fn send(
&self,
recipient: &AccountId,
amount: Vec<Coin>,
memo: impl Into<String> + Send + 'static,
fee: Option<Fee>,
) -> Result<TxResponse, NyxdError>
pub async fn send( &self, recipient: &AccountId, amount: Vec<Coin>, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<TxResponse, NyxdError>
Send funds from one address to another
Sourcepub async fn send_multiple(
&self,
msgs: Vec<(AccountId, Vec<Coin>)>,
memo: impl Into<String> + Send + 'static,
fee: Option<Fee>,
) -> Result<TxResponse, NyxdError>
pub async fn send_multiple( &self, msgs: Vec<(AccountId, Vec<Coin>)>, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<TxResponse, NyxdError>
Send funds from one address to multiple others
Sourcepub async fn grant_allowance(
&self,
grantee: &AccountId,
spend_limit: Vec<Coin>,
expiration: Option<SystemTime>,
allowed_messages: Vec<String>,
memo: impl Into<String> + Send + 'static,
fee: Option<Fee>,
) -> Result<TxResponse, NyxdError>
pub async fn grant_allowance( &self, grantee: &AccountId, spend_limit: Vec<Coin>, expiration: Option<SystemTime>, allowed_messages: Vec<String>, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<TxResponse, NyxdError>
Grant a fee allowance from one address to another
Sourcepub async fn revoke_allowance(
&self,
grantee: &AccountId,
memo: impl Into<String> + Send + 'static,
fee: Option<Fee>,
) -> Result<TxResponse, NyxdError>
pub async fn revoke_allowance( &self, grantee: &AccountId, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<TxResponse, NyxdError>
Revoke a fee allowance from one address to another
pub async fn execute<M>( &self, contract_address: &AccountId, msg: &M, fee: Option<Fee>, memo: impl Into<String> + Send + 'static, funds: Vec<Coin>, ) -> Result<ExecuteResult, NyxdError>
pub async fn execute_multiple<I, M>( &self, contract_address: &AccountId, msgs: I, fee: Option<Fee>, memo: impl Into<String> + Send + 'static, ) -> Result<ExecuteResult, NyxdError>
pub async fn upload( &self, wasm_code: Vec<u8>, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<UploadResult, NyxdError>
pub async fn instantiate<M>( &self, code_id: ContractCodeId, msg: &M, label: String, memo: impl Into<String> + Send + 'static, options: Option<InstantiateOptions>, fee: Option<Fee>, ) -> Result<InstantiateResult, NyxdError>
pub async fn update_admin( &self, contract_address: &AccountId, new_admin: &AccountId, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<ChangeAdminResult, NyxdError>
pub async fn clear_admin( &self, contract_address: &AccountId, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<ChangeAdminResult, NyxdError>
pub async fn migrate<M>( &self, contract_address: &AccountId, code_id: ContractCodeId, msg: &M, memo: impl Into<String> + Send + 'static, fee: Option<Fee>, ) -> Result<MigrateResult, NyxdError>